@@ -1,4 +1,3 @@
-
 # Package build setup ----------------------------------------------------
 
 test_that("with*_latex context fixtures force has_latex result", {
@@ -14,22 +13,69 @@ test_that("with*_latex context fixtures force has_latex result", {
 
 # expect `manual=TRUE` & empty `args` not to add build --no-manual flag
 test_that("source build setup accept args and/or parameterized helpers", {
-  expect_silent(res <- with_latex({
-    build_setup_source(
+  expect_silent(
+    res <- with_latex({
+      build_setup_source(
+        file.path(testthat::test_path(), "testDummy"),
+        file.path(tempdir(), "testDummyBuild"),
+        vignettes = FALSE,
+        manual = TRUE,
+        clean_doc = FALSE,
+        args = c(),
+        needs_compilation = FALSE
+      )
+    })
+  )
+  expect_true(!"--no-manual" %in% res$args)
+
+  # expect `manual=FALSE` to affect build --no-manual flag
+  expect_silent(
+    res <- with_latex({
+      build_setup_source(
+        file.path(testthat::test_path(), "testDummy"),
+        file.path(tempdir(), "testDummyBuild"),
+        vignettes = FALSE,
+        manual = FALSE,
+        clean_doc = FALSE,
+        args = c(),
+        needs_compilation = FALSE
+      )
+    })
+  )
+  expect_true("--no-manual" %in% res$args)
+
+  # expect `args` "--no-manual" to affect build --no-manual flag
+  expect_silent(
+    res <- with_latex({
+      build_setup_source(
+        file.path(testthat::test_path(), "testDummy"),
+        file.path(tempdir(), "testDummyBuild"),
+        vignettes = FALSE,
+        manual = TRUE,
+        clean_doc = FALSE,
+        args = c("--no-manual"),
+        needs_compilation = FALSE
+      )
+    })
+  )
+  expect_true("--no-manual" %in% res$args)
+
+  expect_silent(
+    res <- build_setup_source(
       file.path(testthat::test_path(), "testDummy"),
       file.path(tempdir(), "testDummyBuild"),
-      vignettes = FALSE,
-      manual = TRUE,
+      vignettes = TRUE,
+      manual = FALSE,
       clean_doc = FALSE,
       args = c(),
       needs_compilation = FALSE
     )
-  }))
-  expect_true(!"--no-manual" %in% res$args)
+  )
+  expect_true(!"--no-build-vignettes" %in% res$args)
 
-  # expect `manual=FALSE` to affect build --no-manual flag
-  expect_silent(res <- with_latex({
-    build_setup_source(
+  # expect `vignettes=FALSE` to affect build --no-build-vignettes flag
+  expect_silent(
+    res <- build_setup_source(
       file.path(testthat::test_path(), "testDummy"),
       file.path(tempdir(), "testDummyBuild"),
       vignettes = FALSE,
@@ -38,56 +84,21 @@ test_that("source build setup accept args and/or parameterized helpers", {
       args = c(),
       needs_compilation = FALSE
     )
-  }))
-  expect_true("--no-manual" %in% res$args)
-
-  # expect `args` "--no-manual" to affect build --no-manual flag
-  expect_silent(res <- with_latex({
-    build_setup_source(
-      file.path(testthat::test_path(), "testDummy"),
-      file.path(tempdir(), "testDummyBuild"),
-      vignettes = FALSE,
-      manual = TRUE,
-      clean_doc = FALSE,
-      args = c("--no-manual"),
-      needs_compilation = FALSE
-    )
-  }))
-  expect_true("--no-manual" %in% res$args)
-
-  expect_silent(res <- build_setup_source(
-    file.path(testthat::test_path(), "testDummy"),
-    file.path(tempdir(), "testDummyBuild"),
-    vignettes = TRUE,
-    manual = FALSE,
-    clean_doc = FALSE,
-    args = c(),
-    needs_compilation = FALSE
-  ))
-  expect_true(!"--no-build-vignettes" %in% res$args)
-
-  # expect `vignettes=FALSE` to affect build --no-build-vignettes flag
-  expect_silent(res <- build_setup_source(
-    file.path(testthat::test_path(), "testDummy"),
-    file.path(tempdir(), "testDummyBuild"),
-    vignettes = FALSE,
-    manual = FALSE,
-    clean_doc = FALSE,
-    args = c(),
-    needs_compilation = FALSE
-  ))
+  )
   expect_true("--no-build-vignettes" %in% res$args)
 
   # expect `arg` `--no-build-vignettes` to produce --no-build-vignettes flag
-  expect_silent(res <- build_setup_source(
-    file.path(testthat::test_path(), "testDummy"),
-    file.path(tempdir(), "testDummyBuild"),
-    vignettes = TRUE,
-    manual = FALSE,
-    clean_doc = FALSE,
-    args = c("--no-build-vignettes"),
-    needs_compilation = FALSE
-  ))
+  expect_silent(
+    res <- build_setup_source(
+      file.path(testthat::test_path(), "testDummy"),
+      file.path(tempdir(), "testDummyBuild"),
+      vignettes = TRUE,
+      manual = FALSE,
+      clean_doc = FALSE,
+      args = c("--no-build-vignettes"),
+      needs_compilation = FALSE
+    )
+  )
   expect_true("--no-build-vignettes" %in% res$args)
 })
 
@@ -111,7 +122,12 @@ test_that("binary builds return correct filenames", {
 
 test_that("can build package without src without compiler", {
   without_compiler({
-    path <- build("testDummy", binary = TRUE, dest_path = tempdir(), quiet = TRUE)
+    path <- build(
+      "testDummy",
+      binary = TRUE,
+      dest_path = tempdir(),
+      quiet = TRUE
+    )
     on.exit(unlink(path))
 
     expect_true(file.exists(path))
@@ -122,7 +138,12 @@ test_that("can build package without src without compiler", {
 # Package with src code ---------------------------------------------------
 
 test_that("source builds return correct filenames", {
-  path <- build("testWithSrc", dest_path = tempdir(), quiet = TRUE, register_routines = FALSE)
+  path <- build(
+    "testWithSrc",
+    dest_path = tempdir(),
+    quiet = TRUE,
+    register_routines = FALSE
+  )
   on.exit(unlink(path))
 
   expect_true(file.exists(path))
@@ -130,9 +151,11 @@ test_that("source builds return correct filenames", {
 
 test_that("build package with src requires compiler", {
   without_compiler({
-    expect_error(
-      build("testWithSrc", dest_path = tempdir(), quiet = TRUE),
-      "Could not find tools"
+    expect_snapshot(
+      error = TRUE,
+      suppressMessages(
+        build("testWithSrc", dest_path = tempdir(), quiet = TRUE)
+      )
     )
   })
 })
@@ -143,9 +166,12 @@ test_that("package tarball binary build", {
   path <- build("testDummy", dest_path = tempdir(), quiet = TRUE)
   on.exit(unlink(path), add = TRUE)
 
-  path2 <- build(path,
-    dest_path = tempdir(), quiet = TRUE,
-    binary = TRUE, needs_compilation = FALSE,
+  path2 <- build(
+    path,
+    dest_path = tempdir(),
+    quiet = TRUE,
+    binary = TRUE,
+    needs_compilation = FALSE,
     compile_attributes = FALSE
   )
   on.exit(unlink(path2), add = TRUE)
@@ -158,56 +184,65 @@ test_that("package tarball binary build errors", {
   path <- build("testDummy", dest_path = tempdir(), quiet = TRUE)
   on.exit(unlink(path), add = TRUE)
 
-  expect_error(
-    build(path, dest_path = tempdir(), quiet = TRUE),
-    "binary"
+  expect_snapshot(
+    error = TRUE,
+    build(path, dest_path = tempdir(), quiet = TRUE)
   )
-  expect_error(
-    build(path,
-      dest_path = tempdir(), quiet = TRUE, binary = TRUE,
-      needs_compilation = FALSE, compile_attributes = TRUE
-    ),
-    "compile_attributes"
+  expect_snapshot(
+    error = TRUE,
+    build(
+      path,
+      dest_path = tempdir(),
+      quiet = TRUE,
+      binary = TRUE,
+      needs_compilation = FALSE,
+      compile_attributes = TRUE
+    )
   )
 })
 
 test_that("warnings can be turned into errors", {
   src <- withr::local_tempdir()
   dest <- withr::local_tempdir()
-  file.copy(test_path("testDummy"), src, recursive = TRUE)
+  file.copy(test_path("testDummy"), src, recursive = TRUE, copy.mode = FALSE)
 
   withr::local_options(pkg.build_stop_for_warnings = TRUE)
   expect_silent(
     build(file.path(src, "testDummy"), dest_path = dest, quiet = TRUE)
   )
 
-  dir.create(file.path(src, "testDummy", "inst"), recursive = TRUE, showWarnings = FALSE)
+  dir.create(
+    file.path(src, "testDummy", "inst"),
+    recursive = TRUE,
+    showWarnings = FALSE
+  )
   saveRDS(1:10, file.path(src, "testDummy", "inst", "testthat-problems.rds"))
 
   # No warning/error on R <= 3.5
   if (getRversion() <= "3.6") skip("Needs R 3.5.0")
 
   # Warning looks different on older R
-  if (getRversion() >= "4.1") {
-    expect_snapshot(
-      error = TRUE,
-      build(file.path(src, "testDummy"), dest_path = dest, quiet = TRUE),
-      transform = function(x) {
-        x <- sub("\u2018", "'", x, fixed = TRUE)
-        x <- sub("\u2019", "'", x, fixed = TRUE)
-        x <- sub("checking for file '.*'", "checking for file '<file>'", x)
-        x
+  expect_snapshot(
+    error = TRUE,
+    {
+      if (getRversion() >= "4.1") {
+        build(file.path(src, "testDummy"), dest_path = dest, quiet = TRUE)
+      } else {
+        suppressMessages(build(
+          file.path(src, "testDummy"),
+          dest_path = dest,
+          quiet = TRUE
+        ))
       }
-    )
-  } else {
-    expect_error(
-      suppressMessages(build(
-        file.path(src, "testDummy"),
-        dest_path = dest,
-        quiet = TRUE
-      ))
-    )
-  }
+    },
+    transform = function(x) {
+      x <- sub("\u2018", "'", x, fixed = TRUE)
+      x <- sub("\u2019", "'", x, fixed = TRUE)
+      x <- sub("checking for file '.*'", "checking for file '<file>'", x)
+      x
+    },
+    variant = if (getRversion() >= "4.1") "new" else "old"
+  )
 })
 
 test_that("Config/build/clean-inst-doc FALSE", {
@@ -235,7 +270,7 @@ test_that("Config/build/clean-inst-doc TRUE", {
   if (Sys.which("pandoc") == "") skip("No pandoc")
   src <- withr::local_tempdir()
   dest <- withr::local_tempdir()
-  file.copy(test_path("testInstDoc"), src, recursive = TRUE)
+  file.copy(test_path("testInstDoc"), src, recursive = TRUE, copy.mode = FALSE)
 
   desc::desc_set(
     "Config/build/clean-inst-doc" = "TRUE",
@@ -262,7 +297,7 @@ test_that("Config/build/clean-inst-doc TRUE", {
 test_that("bootstrap.R runs on build if present", {
   src <- withr::local_tempdir()
   dest <- withr::local_tempdir()
-  file.copy(test_path("testDummy"), src, recursive = TRUE)
+  file.copy(test_path("testDummy"), src, recursive = TRUE, copy.mode = FALSE)
 
   writeLines(
     c(
@@ -295,7 +330,7 @@ test_that("bootstrap.R runs on build if present", {
 test_that("bootstrap.R does not run if Config/build/bootstrap is not TRUE", {
   src <- withr::local_tempdir()
   dest <- withr::local_tempdir()
-  file.copy(test_path("testDummy"), src, recursive = TRUE)
+  file.copy(test_path("testDummy"), src, recursive = TRUE, copy.mode = FALSE)
 
   writeLines(
     c(
@@ -323,7 +358,7 @@ test_that("bootstrap.R does not run if Config/build/bootstrap is not TRUE", {
 test_that("bootstrap.R can output stdout, stderr, and warnings when run", {
   src <- withr::local_tempdir()
   dest <- withr::local_tempdir()
-  file.copy(test_path("testDummy"), src, recursive = TRUE)
+  file.copy(test_path("testDummy"), src, recursive = TRUE, copy.mode = FALSE)
 
   writeLines(
     c(
